@@ -73,6 +73,8 @@ def clone(args):
 
 def backup(args):
     dir = const.BACKUP_DIR.joinpath(args.name)
+    shutil.copytree(const.DOTFILES_SAVE_DIR, dir)
+    print(f"{SUCCESS} Saved backup to ${dir.relative_to(const.HOME)}{Fore.RESET}")
 
 def init(args):
     lib.write_file(const.MYCFG_CONFIG_DIR.joinpath(".gitignore"), "\n".join(const.DEFAULT_GIT_IGNORE))
