@@ -24,7 +24,7 @@ DEFAULT_CONFIG_CONTENT = {
     "package-managers": {},
 }
 
-DEFAULT_GIT_IGNORE = ["meta.json"]
+DEFAULT_GIT_IGNORE = ["meta.json", "backups/"]
 
 PATH_VARIABLES = {
     "$HOME": HOME,
