@@ -48,7 +48,8 @@ def get_repo_url(string: str):
         return string
     if any(map(string.startswith, ["gh:", "github:"])):
         parts = string.split(":")[1].split("/")
-        username, repo_name = parts[0], parts[1] if len(parts) > 1 else "dotfiles"
+        username = parts[0]
+        repo_name = parts[1] if len(parts) > 1 else "dotfiles"
         return f"https://github.com/{username}/{repo_name}"
     else:
         return None
